/*========================================================================
 * Copyright (C) GemTalk Systems 1986-2016.  All Rights Reserved..
 *
 * Name - asyncio.c
 *
 * Description - Verify that async disk I/O is functional on a Unix host
 *
 * $Id: asyncio.c,v 1.10 2008-01-09 19:03:03 stever Exp $
 *
 *========================================================================
 */

#include "global.ht" 
#include <flag.ht> /* MUST BE FIRST! */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <errno.h>
#include <unistd.h> /* for access() */
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>


#if !defined(FLG_MSWIN32)
#include <unistd.h>
#if !defined(FLG_LINUX_UNIX)
#include <sys/buf.h>
#endif
#endif

#if defined (FLG_SOLARIS_UNIX)
#include <sys/types.h>
#include <sys/asynch.h>
#elif defined(FLG_USE_POSIX_AIO)
#include <aio.h>
#endif

#define HOSTAIO_MAX_OPS 50
#define BUFFER_SIZE 1024
static char bufPtr[BUFFER_SIZE];

static void showErrno(int num)
{
  printf("  errno = %d (%s)\n", num, strerror(num));
}

static int init(const char *fname)
{
  return 0;
}


static int doWrite(int fd)
{
#if defined(FLG_SOLARIS_UNIX)
  aio_result_t aioResult;

  if (aiowrite(fd, bufPtr, BUFFER_SIZE, 0 /* offset */, SEEK_SET,
      &aioResult) < 0) {
    fprintf(stderr, "aiowrite() failed\n");
    showErrno(errno);
    return 1;
    }
  return 0;

#elif defined(FLG_USE_POSIX_AIO)
  struct aiocb aioReq;

  memset(&aioReq, 0, sizeof(aioReq));
  aioReq.aio_fildes = fd;
  aioReq.aio_reqprio = 0;
  aioReq.aio_lio_opcode = LIO_WRITE;
  aioReq.aio_buf = bufPtr;
  aioReq.aio_nbytes = BUFFER_SIZE;
  aioReq.aio_offset = 0;

  if (aio_write(&aioReq) < 0) {
    fprintf(stderr, "aio_write() failed\n");
    showErrno(errno);
    return 1;
  }
  return 0;
#endif
}


#if defined(MSDOS)
int main()
#else
int main(int argc, char *argv[])
#endif
{
  int result = 0;
  int fd;

  if (argc != 2) {
    fprintf(stderr, "Usage: asyncio <scratchFile>\n");
    fprintf(stderr, "    scratchFile is the file to write with\n");

    fprintf(stderr, "Tests validity of async disk i/o on this host.\n");
    return 1;
    }

  fd = open(argv[1], O_RDWR, S_IREAD|S_IWRITE|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH);
  if (fd == -1) {
    fprintf(stderr, "open() failure on %s\n", argv[1]);
    showErrno(errno);
    return 1;
    }

  if (init(argv[1]))
    return 1;

  if (doWrite(fd))
    result = 1;

  return result;
}
