!=========================================================================
! Copyright (C) GemTalk Systems 1986-2016.  All Rights Reserved.
!
! $Id: gcuser.gs,v 1.12 2008-01-09 19:02:33 stever Exp $
!
! Description - Create the GcUser (Garbage Collector) user account.
! 
! Repository conversion - this file is used
!
!=======================================================================

! login as SystemUser
set user SystemUser pass swordfish
iferror exit
login 
iferror

expectvalue %String
run
   "Expect a three element Array of user IDs: SystemUser, DataCurator,
    and GcUser "
| gcUser newSegment newUser gcUserGlobals |

gcUser := AllUsers detect: [ :x | x userId asString = 'GcUser' ] ifNone: [nil].
gcUser ~~ nil
  ifTrue: [
    "GcUser already exists. Set its password."
    gcUser password: 'swordfish'.
    ^ 'GcUser already exists'
    ]
  ifFalse: [
    "Create a new GcUser"
    newSegment := Segment newInRepository: SystemRepository.
    newUser := UserProfile newWithUserId: 'GcUser'
                         password: #swordfish
                         defaultSegment: newSegment
                         privileges: #( #GarbageCollection)
                         inGroups: #()
                         compilerLanguage: #ASCII.
    newSegment worldAuthorization: #read;
             owner: newUser.

    " AllUsers add: newUser. --- no longer needed "

    " Put GcUser in SystemUser's UserGlobals "
    UserGlobals at: #GcUser put: newUser.

    " Put GcUser in DataCurator's UserGlobals"
    ((AllUsers userWithId: #DataCurator) resolveSymbol: #UserGlobals) value at: 
       #GcUser put: newUser.

    " Put GcUser in its own UserGlobals"
    gcUserGlobals := (newUser resolveSymbol: #UserGlobals) value.
    gcUserGlobals at: #GcUser put: newUser.

    ^ 'created GcUser'
    ]
%

commit

logout

set user GcUser pass swordfish
iferror exit
login 
iferror

run
UserGlobals at:#defaultValues put:

'
"This String documents the default values for the garbage collector.
 Execute this GemStone Smalltalk source and commit to reset all default values"

UserGlobals at: #reclaimSleepTime  put:   10.  "must be >= 1"
"The maximum amount of time (in seconds) that the process should sleep.
 The garbage collector always makes sure that there is no work scheduled for
 it to do before it goes to sleep."

"Maximum and minimum number of pages to process in a single reclaim."
UserGlobals at: #reclaimMinPages put:   40.  "must be >= 10" 
UserGlobals at: #reclaimMaxPages put:  200.  "must be >= (reclaimMinPages + 5)"

"EpochGarbageCollection parameters"
UserGlobals at: #epochGcEnabled put: true.  

UserGlobals at: #epochGcTimeLimit put: 900. "900 seconds = 15 minutes" 
                                               "must be >= 5 seconds"
"epochGcTimeLimit controls the maximum frequency of epochs, for example, the
 default value set here does not allow more than one epoch every 15 minutes."

UserGlobals at: #epochGcTransLimit put: 5000.  "number of transactions"
UserGlobals at: #epochGcByteLimit put: 5000000. "bytes of new/modified objects"
"Either the epochGcTransLimit or epochGcByteLimit must be exceeded since the
 last epoch in order to trigger a new epoch."

UserGlobals at: #GemIOLimit put: 5000. "must be >= 1"  "also in upgrade code"

UserGlobals at: #deferEpochReclaimThreshold put: 1000.
  "When running with a single GcGem, if the number of pages needing reclaiming 
   exceeds this value, defer further execution of epochGc.  This parameter is
   ignored when running with a dual RCL/EPC GcGem configuration." 

UserGlobals at: #sleepTimeBetweenReclaim put: 0.
  "Amount of time to sleep after a reclaim or promotion that did work."

UserGlobals at: #reclaimDeadEnabled  put: true.
  "Controls whether the reclaim will try to clean up dead objects."

"NOTE:  following parameters are for *experts* only! They adjust GC behavior
 in ways that will only benefit certain system under limited conditions.  Read
 the comments for details."

UserGlobals at: #commitHeartbeatInterval put: 300.
  "If this number of seconds passes without any other commits being
   performed by the system, the GcGem will execute a no-op commit.
   This acts as a heartbeat to keep commit records moving, since
   certain GC operations can appear to hang in a totally quiet system."

UserGlobals at: #allSymbolsMinTimeBetweenBmRebuilds put: 60.
  "The minimum interval in seconds between AllSymbols bitmap rebuilds
   performed by the GcGem or EpochGcGem.  Minimum value is 5, maximum
   value is 536870911."

UserGlobals at: #allSymbolsMinCommitsBetweenBmRebuilds put: 500.
  "The minimum number of total commits to the repository between AllSymbols
   bitmap rebuilds performed by the GcGem or EpochGcGem.  Minimum value is 0,
   which disables symbol bitmap rebuilds except immediately after the first
   GcGem/EpochGcGem login after the stone is started.  Maximum value is
   536870911."

"NOTE: values which exceed the specified limits (min or max) will be
  cause the garbage collector to ignore the value stored in UserGlobals,
  and the documented limit will be silently used."

'  .
^ true
%

! fix bug 10037 ; preserve non-default values during repository upgrade
run
UserGlobals at: #reclaimMaxPages ifAbsent:[
  "initial 4.1 filein, define all values"
  ( (UserGlobals at: #defaultValues) _compileInContext: nil
         symbolList: System myUserProfile symbolList ) _executeInContext: nil .
  ].
UserGlobals at: #GemIOLimit ifAbsent:[
  "upgrading a 4.0 repository to 4.1"
  UserGlobals at: #promoteDeadLimit put: 1000 .
  UserGlobals at: #GemIOLimit put: 5000 .
  (UserGlobals at:#reclaimMaxPages) = 1000 ifTrue:[
    "change 4.0 default to 4.1 default" 
    UserGlobals at:#reclaimMaxPages put: 200 .
    ] .
  ] .
^ true
%

! BUGFIX 19218/26548 - if new GC parameters don't exist, create them
run
UserGlobals at: #reclaimDeadEnabled ifAbsent: [
  UserGlobals at: #reclaimDeadEnabled  put: true ].
UserGlobals at: #commitHeartbeatInterval ifAbsent: [
  UserGlobals at: #commitHeartbeatInterval put: 300 ].
UserGlobals at: #allSymbolsMinTimeBetweenBmRebuilds ifAbsent: [
  UserGlobals at: #allSymbolsMinTimeBetweenBmRebuilds put: 60 ].
UserGlobals at: #allSymbolsMinCommitsBetweenBmRebuilds ifAbsent: [
  UserGlobals at: #allSymbolsMinCommitsBetweenBmRebuilds put: 500 ].
^ true
%


! Remove keys obsolete in 6.2 and later
run
UserGlobals removeKey: #reclaimStats ifAbsent: [ ] .
UserGlobals removeKey: #reclaimStatsEnabled ifAbsent: [ ] .
UserGlobals removeKey: #epochGcStatsEnabled ifAbsent: [ ] .
UserGlobals removeKey: #epochGcStats ifAbsent: [ ] .
^true
%

stack
commit

logout

